@@ -33,6 +33,8 @@ class PriceFocus(Focus):
     def evaluate_buy(
         self, symbol: str, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
     ) -> Tuple[bool, str]:
+        if not candles:
+            return False, "Not enough data"
 
         is_up_last_periods, message = self.up_last(candle_data=candles, a_time=to_est(), periods=self.num_periods)
 
