@@ -4,6 +4,7 @@ from copy import deepcopy
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Any, Dict, Optional
+from uuid import UUID
 
 from ctlml_commons.util.date_utils import convert_dates, datetime_to_str
 from ctlml_commons.util.num_utils import convert_floats
@@ -13,14 +14,14 @@ from ctlml_commons.util.num_utils import convert_floats
 class Lot:
     """Uniquely identifies an ingress execution, i.e. BUY 10 of ABCD at LIMIT price of 0.1."""
 
-    id: str  # Internal id
+    id: UUID  # Internal id
     symbol: str  # Ticker
     shares: float  # Shares
     purchase_price: float  # Price per share
     notes: str  # Summary of why this lot was created
     investment_strategy_data: str
     purchase_time: datetime  # Purchase time
-    b_id: Optional[str] = None  # Brokerage external id
+    b_id: Optional[UUID] = None  # Brokerage external id
 
     def serialize(self) -> Dict[str, Any]:
         data: Dict[str, Any] = self.__dict__
@@ -29,7 +30,7 @@ class Lot:
 
         return data
 
-    def add_brokerage_id(self, b_id: str) -> Lot:
+    def add_brokerage_id(self, b_id: UUID) -> Lot:
         return Lot(
             id=self.id,
             symbol=self.symbol,
